Package: oeli
Type: Package
Title: Some Utilities for Developing Data Science Software
Version: 0.7.6
Authors@R: person(
    given = "Lennart", 
    family = "Oelschl\u00e4ger", 
    email = "oelschlaeger.lennart@gmail.com", 
    role = c("aut", "cre")
  )
Description: A collection of general-purpose helper functions that I (and maybe 
    others) find useful when developing data science software. Includes tools 
    for simulation, data transformation, input validation, and more.
License: GPL (>= 3)
Encoding: UTF-8
Config/testthat/edition: 3
RoxygenNote: 7.3.3
Depends: R (>= 4.1.0)
Imports: benchmarkme, checkmate, cli, cubature, dplyr, future,
        future.apply, ggplot2, glue, hexSticker, progressr, R6, Rcpp,
        SimMultiCorrData, stats, tibble, tools, utils
LinkingTo: mvtnorm, Rcpp (>= 1.1.1), RcppArmadillo, testthat
Suggests: knitr, rmarkdown, testthat (>= 3.0.0), xml2
URL: https://github.com/loelschlaeger/oeli,
        http://loelschlaeger.de/oeli/
BugReports: https://github.com/loelschlaeger/oeli/issues
LazyData: true
NeedsCompilation: yes
Packaged: 2026-04-22 22:04:13 UTC; loelschlaeger
Author: Lennart Oelschläger [aut, cre]
Maintainer: Lennart Oelschläger <oelschlaeger.lennart@gmail.com>
Repository: CRAN
Date/Publication: 2026-04-23 05:10:02 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-04-25 13:55:42 UTC; unix
Archs: oeli.so.dSYM
