# Generated by roxygen2: do not edit by hand

export(Dictionary)
export(M)
export(Simulator)
export(Storage)
export(assert_correlation_matrix)
export(assert_covariance_matrix)
export(assert_list_of_lists)
export(assert_missing)
export(assert_numeric_vector)
export(assert_one_hot_matrix)
export(assert_probability_vector)
export(assert_transition_probability_matrix)
export(check_correlation_matrix)
export(check_covariance_matrix)
export(check_list_of_lists)
export(check_missing)
export(check_numeric_vector)
export(check_one_hot_matrix)
export(check_probability_vector)
export(check_transition_probability_matrix)
export(chol_to_cov)
export(chunk_vector)
export(correlated_regressors)
export(cov_to_chol)
export(ddirichlet)
export(ddirichlet_cpp)
export(delete_columns_data.frame)
export(delta)
export(diff_cov)
export(dmixnorm)
export(dmixnorm_cpp)
export(dmvnorm)
export(dmvnorm_cpp)
export(do.call_timed)
export(dtnorm)
export(dtnorm_cpp)
export(dttnorm)
export(dttnorm_cpp)
export(dwishart)
export(dwishart_cpp)
export(equidistant_vectors)
export(find_namespace_calls)
export(function_arguments)
export(function_body)
export(function_defaults)
export(gaussian_tv)
export(group_data.frame)
export(identical_structure)
export(input_check_response)
export(insert_matrix_column)
export(insert_vector_entry)
export(map_indices)
export(match_arg)
export(match_numerics)
export(matrix_diagonal_indices)
export(matrix_indices)
export(merge_lists)
export(occurrence_info)
export(package_logo)
export(permutations)
export(pmixnorm)
export(pmixnorm_cpp)
export(pmvnorm)
export(pmvnorm_cpp)
export(print_data.frame)
export(print_matrix)
export(quiet)
export(rdirichlet)
export(rdirichlet_cpp)
export(rmixnorm)
export(rmixnorm_cpp)
export(rmvnorm)
export(rmvnorm_cpp)
export(round_data.frame)
export(rtnorm)
export(rtnorm_cpp)
export(rttnorm)
export(rttnorm_cpp)
export(rwishart)
export(rwishart_cpp)
export(sample_correlation_matrix)
export(sample_covariance_matrix)
export(sample_transition_probability_matrix)
export(simulate_markov_chain)
export(split_vector_at)
export(stationary_distribution)
export(subsets)
export(system_information)
export(test_correlation_matrix)
export(test_covariance_matrix)
export(test_list_of_lists)
export(test_missing)
export(test_numeric_vector)
export(test_one_hot_matrix)
export(test_probability_vector)
export(test_transition_probability_matrix)
export(timed)
export(try_silent)
export(undiff_cov)
export(unexpected_error)
export(unique_chol)
export(user_confirm)
export(variable_name)
export(vector_occurrence)
importFrom(R6,R6Class)
importFrom(Rcpp,compileAttributes)
importFrom(SimMultiCorrData,calc_theory)
importFrom(SimMultiCorrData,rcorrvar)
importFrom(SimMultiCorrData,valid_corr)
importFrom(benchmarkme,get_cpu)
importFrom(benchmarkme,get_ram)
importFrom(checkmate,assert)
importFrom(checkmate,assert_atomic_vector)
importFrom(checkmate,assert_character)
importFrom(checkmate,assert_choice)
importFrom(checkmate,assert_count)
importFrom(checkmate,assert_data_frame)
importFrom(checkmate,assert_flag)
importFrom(checkmate,assert_function)
importFrom(checkmate,assert_int)
importFrom(checkmate,assert_integerish)
importFrom(checkmate,assert_list)
importFrom(checkmate,assert_matrix)
importFrom(checkmate,assert_names)
importFrom(checkmate,assert_number)
importFrom(checkmate,assert_numeric)
importFrom(checkmate,assert_string)
importFrom(checkmate,assert_subset)
importFrom(checkmate,assert_vector)
importFrom(checkmate,check_atomic_vector)
importFrom(checkmate,check_character)
importFrom(checkmate,check_choice)
importFrom(checkmate,check_class)
importFrom(checkmate,check_count)
importFrom(checkmate,check_data_frame)
importFrom(checkmate,check_directory_exists)
importFrom(checkmate,check_flag)
importFrom(checkmate,check_function)
importFrom(checkmate,check_int)
importFrom(checkmate,check_integerish)
importFrom(checkmate,check_list)
importFrom(checkmate,check_matrix)
importFrom(checkmate,check_names)
importFrom(checkmate,check_number)
importFrom(checkmate,check_numeric)
importFrom(checkmate,check_path_for_output)
importFrom(checkmate,check_string)
importFrom(checkmate,check_subset)
importFrom(checkmate,makeAssertion)
importFrom(checkmate,makeAssertionFunction)
importFrom(checkmate,makeTestFunction)
importFrom(checkmate,test_atomic_vector)
importFrom(checkmate,test_class)
importFrom(checkmate,test_int)
importFrom(checkmate,test_list)
importFrom(checkmate,test_matrix)
importFrom(checkmate,test_string)
importFrom(checkmate,vname)
importFrom(cli,cli_abort)
importFrom(cli,cli_inform)
importFrom(cli,cli_text)
importFrom(cli,cli_warn)
importFrom(cli,style_hyperlink)
importFrom(cubature,hcubature)
importFrom(dplyr,arrange)
importFrom(dplyr,bind_rows)
importFrom(dplyr,filter)
importFrom(future,multisession)
importFrom(future,plan)
importFrom(future.apply,future_lapply)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,theme_void)
importFrom(glue,glue)
importFrom(hexSticker,sticker)
importFrom(progressr,handler_progress)
importFrom(progressr,handlers)
importFrom(progressr,progressor)
importFrom(stats,cor)
importFrom(stats,dist)
importFrom(stats,dnorm)
importFrom(stats,rnorm)
importFrom(stats,runif)
importFrom(tibble,as_tibble)
importFrom(tibble,tibble)
importFrom(tools,package_native_routine_registration_skeleton)
importFrom(utils,combn)
importFrom(utils,head)
importFrom(utils,tail)
useDynLib(oeli, .registration=TRUE)
