# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

#' @rdname ddirichlet
#' @export
ddirichlet_cpp <- function(x, concentration, log = FALSE) {
    .Call(`_oeli_ddirichlet_cpp`, x, concentration, log)
}

#' @rdname ddirichlet
#' @export
rdirichlet_cpp <- function(concentration) {
    .Call(`_oeli_rdirichlet_cpp`, concentration)
}

#' @rdname dmixnorm
#' @export
dmixnorm_cpp <- function(x, mean, Sigma, proportions) {
    .Call(`_oeli_dmixnorm_cpp`, x, mean, Sigma, proportions)
}

#' @rdname dmixnorm
#' @export
pmixnorm_cpp <- function(x, mean, Sigma, proportions, abseps = 1e-3) {
    .Call(`_oeli_pmixnorm_cpp`, x, mean, Sigma, proportions, abseps)
}

#' @rdname dmixnorm
#' @export
rmixnorm_cpp <- function(mean, Sigma, proportions) {
    .Call(`_oeli_rmixnorm_cpp`, mean, Sigma, proportions)
}

#' @rdname dmvnorm
#' @export
dmvnorm_cpp <- function(x, mean, Sigma, log = FALSE) {
    .Call(`_oeli_dmvnorm_cpp`, x, mean, Sigma, log)
}

#' @rdname dmvnorm
#' @export
pmvnorm_cpp <- function(x, mean, Sigma, abseps = 1e-3) {
    .Call(`_oeli_pmvnorm_cpp`, x, mean, Sigma, abseps)
}

#' @rdname dmvnorm
#' @export
rmvnorm_cpp <- function(mean, Sigma, log = FALSE) {
    .Call(`_oeli_rmvnorm_cpp`, mean, Sigma, log)
}

#' @rdname dtnorm
#' @export
dtnorm_cpp <- function(x, mean, sd, point, above, log = FALSE) {
    .Call(`_oeli_dtnorm_cpp`, x, mean, sd, point, above, log)
}

#' @rdname dtnorm
#' @export
dttnorm_cpp <- function(x, mean, sd, lower, upper, log = FALSE) {
    .Call(`_oeli_dttnorm_cpp`, x, mean, sd, lower, upper, log)
}

#' @rdname dtnorm
#' @export
rtnorm_cpp <- function(mean, sd, point, above, log = FALSE) {
    .Call(`_oeli_rtnorm_cpp`, mean, sd, point, above, log)
}

#' @rdname dtnorm
#' @export
rttnorm_cpp <- function(mean, sd, lower, upper, log = FALSE) {
    .Call(`_oeli_rttnorm_cpp`, mean, sd, lower, upper, log)
}

#' @rdname dwishart
#' @export
dwishart_cpp <- function(x, df, scale, log = FALSE, inv = FALSE) {
    .Call(`_oeli_dwishart_cpp`, x, df, scale, log, inv)
}

#' @rdname dwishart
#' @export
rwishart_cpp <- function(df, scale, inv = FALSE) {
    .Call(`_oeli_rwishart_cpp`, df, scale, inv)
}

# Register entry points for exported C++ functions
methods::setLoadAction(function(ns) {
    .Call(`_oeli_RcppExport_registerCCallable`)
})
