# dictionary with optimizers works

    Code
      print(optimizer_dictionary)
    Output
      <Dictionary> 
      No elements contained.

---

    Code
      print(optimizer_dictionary)
    Output
      <Dictionary> 
      Keys: 
      - stats::nlm
      - stats::optim

